==> v0.31.tar.gz: lumixengine/README.md <==
# Lumix Engine
---------

[![Coverity Scan Build Status](https://scan.coverity.com/projects/5919/badge.svg)](https://scan.coverity.com/projects/5919)
[![Build status](https://ci.appveyor.com/api/projects/status/7tcoign219kb5bny?svg=true)](https://ci.appveyor.com/project/nem0/lumixengine)
[![Build Status](https://travis-ci.org/nem0/LumixEngine.svg?branch=master)](https://travis-ci.org/nem0/LumixEngine)
[![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/nem0/LumixEngine?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![License](http://img.shields.io/:license-mit-blue.svg)](http://doge.mit-license.org)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/mikulasflorek)


3D Game Engine

* [Getting started](https://github.com/nem0/LumixEngine/wiki/Getting-started)
* [Features](https://github.com/nem0/LumixEngine/wiki/Features)
* [Data repository](https://github.com/nem0/lumixengine_data)
* [Videos](https://www.youtube.com/channel/UCtjtIy0ldsq-9siM1Gm_rXg)
* [Roadmap](https://github.com/nem0/LumixEngine/milestones)

![Editor screenshot](https://cloud.githubusercontent.com/assets/153526/26275242/6e9f7f90-3d5c-11e7-8548-f6ae82d4ba52.jpg)

[3rd party libraries](https://github.com/nem0/lumixengine_3rdparty)

* [bgfx](https://github.com/bkaradzic/bgfx)
* [lua](https://github.com/LuaDist/lua)
* [crunch/crnlib](https://github.com/richgel999/crunch)
* [assimp](https://github.com/assimp/assimp)
* [PhysX](https://developer.nvidia.com/physx-sdk)
* [dear imgui](https://github.com/ocornut/imgui)
* [stb](https://github.com/nothings/stb)
* [SDL](https://www.libsdl.org/)
* [cmft](https://github.com/dariomanesku/cmft)

Project generator

* [Genie](https://github.com/bkaradzic/genie)

Who is using it?

* [On the Hunt](http://www.indiedb.com/games/on-the-hunt)

Contact: mikulas.florek@gamedev.sk

==> v0.32.tar.gz: lumixengine/README.md <==
# Lumix Engine
---------

[![Coverity Scan Build Status](https://scan.coverity.com/projects/5919/badge.svg)](https://scan.coverity.com/projects/5919)
[![Build status](https://ci.appveyor.com/api/projects/status/7tcoign219kb5bny?svg=true)](https://ci.appveyor.com/project/nem0/lumixengine)
[![Build Status](https://travis-ci.org/nem0/LumixEngine.svg?branch=master)](https://travis-ci.org/nem0/LumixEngine)
[![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/nem0/LumixEngine?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![License](http://img.shields.io/:license-mit-blue.svg)](http://doge.mit-license.org)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/mikulasflorek)


3D Game Engine

* [Getting started](https://github.com/nem0/LumixEngine/wiki/Getting-started)
* [Features](https://github.com/nem0/LumixEngine/wiki/Features)
* [Data repository](https://github.com/nem0/lumixengine_data)
* [Videos](https://www.youtube.com/channel/UCtjtIy0ldsq-9siM1Gm_rXg/videos)
* [Plugins](https://github.com/nem0/LumixEngine/wiki/available-plugins)
* [Roadmap](https://github.com/nem0/LumixEngine/milestones)

![Editor screenshot](https://user-images.githubusercontent.com/153526/29975939-9c3db48e-8f38-11e7-80f1-2a777e7a43c8.png)

[3rd party libraries](https://github.com/nem0/lumixengine_3rdparty)

* [bgfx](https://github.com/bkaradzic/bgfx)
* [lua](https://github.com/LuaDist/lua)
* [crunch/crnlib](https://github.com/richgel999/crunch)
* [PhysX](https://developer.nvidia.com/physx-sdk)
* [dear imgui](https://github.com/ocornut/imgui)
* [stb](https://github.com/nothings/stb)
* [SDL](https://www.libsdl.org/)
* [cmft](https://github.com/dariomanesku/cmft)

Project generator

* [Genie](https://github.com/bkaradzic/genie)

Who is using it?

* [On the Hunt](http://www.indiedb.com/games/on-the-hunt)

Contact: mikulas.florek@gamedev.sk
